@@ -5,10 +5,13 @@ import sys
 
 from flask import abort, Flask, Response
 
+from shiva.config import Configurator
+from shiva.utils import get_logger
+
 app = Flask(__name__)
-app.config.from_object('shiva.config')
-if os.environ.get('SHIVA_CONFIG'):
-    app.config.from_envvar('SHIVA_CONFIG')
+app.config.from_object(Configurator())
+
+log = get_logger()
 
 def get_absolute_path(relative_path):
     for mdir in app.config.get('MEDIA_DIRS', []):
@@ -40,7 +43,7 @@ def main():
     except:
         port = 8001
 
-    print("""
+    log.warn("""
     +------------------------------------------------------------+
     | This is a *development* server, for testing purposes only. |
     | Do NOT use in a live environment.                          |
